/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2011 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp11nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp11nid ;

DATA library.&dataset ;
INFILE datafile LRECL=4719;
INPUT
   DISGORGE  1              BUSTEXT $ 2-19           OWNSTEXT $ 20         
   FINSTXT $ 21-52          FINDOTXT $ 53-84         OFENTXT1 $ 85-112     
   OFENTXT2 $ 113           OFENTXT3 $ 114           PRMONTXT $ 115-164    
   ORDERTXT $ 165-263       TYPEOTTX $ 264-462       CPIDN  463-469        
   PSR  470                 JANDC  471               PLEA  472             
   REASONS  473             INDICT  474              SENTRANS  475         
   WRKSHT  476              INCORPYR  477-480        INCORLOC  481         
   ORGTYPE  482             BUSCLAS  483-486         FTEMNUM  487-492      
   FTEMSIGN  493            SELFREP  494             HSMISCND  495         
   PRCRIME  496             PRCIVIL  497             OWNSTRCT  498         
   FINSTDS  499             FINSTDO  500             OFFENSE1  501-502     
   OFFENSE2  503-504        OFFENSE3  505            PRIMOFF  506-507      
   NOCOUNTS  508-510        SOURCES  511             OFFLVL  512-513       
   DETBFINE  514            TOLERNCE  515            HISTORY  516          
   VIOLATE  517             OBSTRUCT  518            COMPLY  519           
   ACCEPT  520-521          CCULPSCO  522-523        FCULPSCO  524-525     
   MINFINML  526-529        MAXFINML  530-532        DISPOSIT  533         
   PROBATN  534-535         COFI  536                PROBMON  537          
   ORDERCE  538             TYPEOTHS  539-540        CRIMPURP  541         
   CANTPAY  542             ADJOFL1  543-544         ADJOFL2  545-546      
   ADJOFLHI  547-548        ADJ_B1  549-550          ADJ_B2  551           
   ADJ_BHI  552-553         ADJ_C1  554-555          ADJ_C2  556           
   ADJ_CHI  557-558         ADJ_D1  559-561          ADJ_D2  562           
   ADJ_DHI  563-565         ADJ_E1  566              ADJ_E2  567           
   ADJ_EHI  568             ADJ_F1  569              ADJ_F2  570           
   ADJ_FHI  571             ADJ_G1  572              ADJ_G2  573           
   ADJ_GHI  574             ADJ_H1  575              ADJ_H2  576           
   ADJ_HHI  577             ADJ_I1  578              ADJ_I2  579           
   ADJ_IHI  580             ADJ_J1  581              ADJ_J2  582           
   ADJ_JHI  583             ADJ_K1  584              ADJ_K2  585           
   ADJ_KHI  586             ADJ_L1  587              ADJ_L2  588           
   ADJ_LHI  589             ADJ_M1  590              ADJ_M2  591           
   ADJ_MHI  592             ADJ_N1  593              ADJ_N2  594           
   ADJ_NHI  595             ADJ_O1  596              ADJ_O2  597           
   ADJ_OHI  598             ADJ_P1  599              ADJ_P2  600           
   ADJ_PHI  601             BASADJ1  602             BASADJ2  603          
   BASADJHI  604            BASE1  605-606           BASE2  607-608        
   BASEHI  609-610          ADJOFR1  611-612         ADJOFR2  613-614      
   ADJOFRHI  615-616        ADJR_B1  617-618         ADJR_B2  619          
   ADJR_BHI  620-621        ADJR_C1  622-623         ADJR_C2  624          
   ADJR_CHI  625-626        ADJR_D1  627             ADJR_D2  628          
   ADJR_DHI  629            ADJR_E1  630             ADJR_E2  631          
   ADJR_EHI  632            ADJR_F1  633             ADJR_F2  634          
   ADJR_FHI  635            ADJR_G1  636             ADJR_G2  637          
   ADJR_GHI  638            ADJR_H1  639             ADJR_H2  640          
   ADJR_HHI  641            ADJR_I1  642             ADJR_I2  643          
   ADJR_IHI  644            ADJR_J1  645             ADJR_J2  646          
   ADJR_JHI  647            ADJR_K1  648             ADJR_K2  649          
   ADJR_KHI  650            ADJR_L1  651             ADJR_L2  652          
   ADJR_LHI  653            ADJR_M1  654             ADJR_M2  655          
   ADJR_MHI  656            ADJR_N1  657             ADJR_N2  658          
   ADJR_NHI  659            ADJR_O1  660             ADJR_O2  661          
   ADJR_OHI  662            ADJR_P1  663             ADJR_P2  664          
   ADJR_PHI  665            BASADR1  666             BASADR2  667          
   BASADRHI  668            BASER1  669-670          BASER2  671           
   BASERHI  672-673         ADJOFS1  674-675         ADJOFS2  676-677      
   ADJOFSHI  678-679        ADJS_B1  680-681         ADJS_B2  682          
   ADJS_BHI  683-684        ADJS_C1  685-686         ADJS_C2  687          
   ADJS_CHI  688-689        ADJS_D1  690-692         ADJS_D2  693          
   ADJS_DHI  694-696        ADJS_E1  697             ADJS_E2  698          
   ADJS_EHI  699            ADJS_F1  700             ADJS_F2  701          
   ADJS_FHI  702            ADJS_G1  703             ADJS_G2  704          
   ADJS_GHI  705            ADJS_H1  706             ADJS_H2  707          
   ADJS_HHI  708            ADJS_I1  709             ADJS_I2  710          
   ADJS_IHI  711            ADJS_J1  712             ADJS_J2  713          
   ADJS_JHI  714            ADJS_K1  715             ADJS_K2  716          
   ADJS_KHI  717            ADJS_L1  718             ADJS_L2  719          
   ADJS_LHI  720            ADJS_M1  721             ADJS_M2  722          
   ADJS_MHI  723            ADJS_N1  724             ADJS_N2  725          
   ADJS_NHI  726            ADJS_O1  727             ADJS_O2  728          
   ADJS_OHI  729            ADJS_P1  730             ADJS_P2  731          
   ADJS_PHI  732            BASADS1  733             BASADS2  734          
   BASADSHI  735            BASES1  736-737          BASES2  738-739       
   BASESHI  740-741         ADJOFC1  742             ADJOFC2  743          
   ADJOFCHI  744            ADJC_B1  745             ADJC_B2  746          
   ADJC_BHI  747            ADJC_C1  748             ADJC_C2  749          
   ADJC_CHI  750            ADJC_D1  751             ADJC_D2  752          
   ADJC_DHI  753            ADJC_E1  754             ADJC_E2  755          
   ADJC_EHI  756            ADJC_F1  757             ADJC_F2  758          
   ADJC_FHI  759            ADJC_G1  760             ADJC_G2  761          
   ADJC_GHI  762            ADJC_H1  763             ADJC_H2  764          
   ADJC_HHI  765            ADJC_I1  766             ADJC_I2  767          
   ADJC_IHI  768            ADJC_J1  769             ADJC_J2  770          
   ADJC_JHI  771            ADJC_K1  772             ADJC_K2  773          
   ADJC_KHI  774            ADJC_L1  775             ADJC_L2  776          
   ADJC_LHI  777            ADJC_M1  778             ADJC_M2  779          
   ADJC_MHI  780            ADJC_N1  781             ADJC_N2  782          
   ADJC_NHI  783            ADJC_O1  784             ADJC_O2  785          
   ADJC_OHI  786            ADJC_P1  787             ADJC_P2  788          
   ADJC_PHI  789            BASADC1  790             BASADC2  791          
   BASADCHI  792            BASEC1  793              BASEC2  794           
   BASECHI  795             ADJL_B1 $ 796            ADJL_B2 $ 797         
   ADJL_BHI $ 798           ADJL_C1 $ 799            ADJL_C2 $ 800         
   ADJL_CHI $ 801           ADJL_D1 $ 802-803        ADJL_D2 $ 804         
   ADJL_DHI $ 805-806       ADJL_E1 $ 807            ADJL_E2 $ 808         
   ADJL_EHI $ 809           ADJL_F1 $ 810            ADJL_F2 $ 811         
   ADJL_FHI $ 812           ADJL_G1 $ 813            ADJL_G2 $ 814         
   ADJL_GHI $ 815           ADJL_H1 $ 816            ADJL_H2 $ 817         
   ADJL_HHI $ 818           ADJL_I1 $ 819            ADJL_I2 $ 820         
   ADJL_IHI $ 821           ADJL_J1 $ 822            ADJL_J2 $ 823         
   ADJL_JHI $ 824           ADJL_K1 $ 825            ADJL_K2 $ 826         
   ADJL_KHI $ 827           ADJL_L1 $ 828            ADJL_L2 $ 829         
   ADJL_LHI $ 830           ADJL_M1 $ 831            ADJL_M2 $ 832         
   ADJL_MHI $ 833           ADJL_N1 $ 834            ADJL_N2 $ 835         
   ADJL_NHI $ 836           ADJL_O1 $ 837-838        ADJL_O2 $ 839         
   ADJL_OHI $ 840-841       ADJL_P1 $ 842            ADJL_P2 $ 843         
   ADJL_PHI $ 844           BASEL1 $ 845             BASEL2 $ 846          
   BASELHI $ 847            ADRL_B1 $ 848            ADRL_B2 $ 849         
   ADRL_BHI $ 850           ADRL_C1 $ 851            ADRL_C2 $ 852         
   ADRL_CHI $ 853           ADRL_D1 $ 854            ADRL_D2 $ 855         
   ADRL_DHI $ 856           ADRL_E1 $ 857            ADRL_E2 $ 858         
   ADRL_EHI $ 859           ADRL_F1 $ 860            ADRL_F2 $ 861         
   ADRL_FHI $ 862           ADRL_G1 $ 863            ADRL_G2 $ 864         
   ADRL_GHI $ 865           ADRL_H1 $ 866            ADRL_H2 $ 867         
   ADRL_HHI $ 868           ADRL_I1 $ 869            ADRL_I2 $ 870         
   ADRL_IHI $ 871           ADRL_J1 $ 872            ADRL_J2 $ 873         
   ADRL_JHI $ 874           ADRL_K1 $ 875            ADRL_K2 $ 876         
   ADRL_KHI $ 877           ADRL_L1 $ 878            ADRL_L2 $ 879         
   ADRL_LHI $ 880           ADRL_M1 $ 881            ADRL_M2 $ 882         
   ADRL_MHI $ 883           ADRL_N1 $ 884            ADRL_N2 $ 885         
   ADRL_NHI $ 886           ADRL_O1 $ 887-888        ADRL_O2 $ 889         
   ADRL_OHI $ 890-891       ADRL_P1 $ 892            ADRL_P2 $ 893         
   ADRL_PHI $ 894           BASERL1 $ 895            BASERL2 $ 896         
   BASERLHI $ 897           ADSL_B1 $ 898            ADSL_B2 $ 899         
   ADSL_BHI $ 900           ADSL_C1 $ 901            ADSL_C2 $ 902         
   ADSL_CHI $ 903           ADSL_D1 $ 904-905        ADSL_D2 $ 906         
   ADSL_DHI $ 907-908       ADSL_E1 $ 909            ADSL_E2 $ 910         
   ADSL_EHI $ 911           ADSL_F1 $ 912            ADSL_F2 $ 913         
   ADSL_FHI $ 914           ADSL_G1 $ 915            ADSL_G2 $ 916         
   ADSL_GHI $ 917           ADSL_H1 $ 918            ADSL_H2 $ 919         
   ADSL_HHI $ 920           ADSL_I1 $ 921            ADSL_I2 $ 922         
   ADSL_IHI $ 923           ADSL_J1 $ 924            ADSL_J2 $ 925         
   ADSL_JHI $ 926           ADSL_K1 $ 927            ADSL_K2 $ 928         
   ADSL_KHI $ 929           ADSL_L1 $ 930            ADSL_L2 $ 931         
   ADSL_LHI $ 932           ADSL_M1 $ 933            ADSL_M2 $ 934         
   ADSL_MHI $ 935           ADSL_N1 $ 936            ADSL_N2 $ 937         
   ADSL_NHI $ 938           ADSL_O1 $ 939            ADSL_O2 $ 940         
   ADSL_OHI $ 941           ADSL_P1 $ 942            ADSL_P2 $ 943         
   ADSL_PHI $ 944           BASESL1 $ 945            BASESL2 $ 946         
   BASESLHI $ 947           ADCL_B1 $ 948            ADCL_B2 $ 949         
   ADCL_BHI $ 950           ADCL_C1 $ 951            ADCL_C2 $ 952         
   ADCL_CHI $ 953           ADCL_D1 $ 954            ADCL_D2 $ 955         
   ADCL_DHI $ 956           ADCL_E1 $ 957            ADCL_E2 $ 958         
   ADCL_EHI $ 959           ADCL_F1 $ 960            ADCL_F2 $ 961         
   ADCL_FHI $ 962           ADCL_G1 $ 963            ADCL_G2 $ 964         
   ADCL_GHI $ 965           ADCL_H1 $ 966            ADCL_H2 $ 967         
   ADCL_HHI $ 968           ADCL_I1 $ 969            ADCL_I2 $ 970         
   ADCL_IHI $ 971           ADCL_J1 $ 972            ADCL_J2 $ 973         
   ADCL_JHI $ 974           ADCL_K1 $ 975            ADCL_K2 $ 976         
   ADCL_KHI $ 977           ADCL_L1 $ 978            ADCL_L2 $ 979         
   ADCL_LHI $ 980           ADCL_M1 $ 981            ADCL_M2 $ 982         
   ADCL_MHI $ 983           ADCL_N1 $ 984            ADCL_N2 $ 985         
   ADCL_NHI $ 986           ADCL_O1 $ 987            ADCL_O2 $ 988         
   ADCL_OHI $ 989           ADCL_P1 $ 990            ADCL_P2 $ 991         
   ADCL_PHI $ 992           BASECL1 $ 993            BASECL2 $ 994-996     
   BASECLHI $ 997           GDLINE1 $ 998-1002       GDLINE2 $ 1003-1007   
   GDSTAT1 $ 1008-1012      GDSTAT2 $ 1013-1017      GDREF1 $ 1018-1022    
   GDREF2 $ 1023-1027       GDCROS1 $ 1028           GDCROS2 $ 1029        
   NOCOMP  1030             GDLINEHI $ 1031-1035     GDSTATHI $ 1036-1040  
   GDREFHI $ 1041-1045      GDCROSHI $ 1046          SMIN1  1047-1050      
   SMIN2  1051              SMIN3  1052              SMIN4  1053           
   SMIN5  1054              SMIN6  1055              SMIN7  1056           
   SMIN8  1057              SMIN9  1058              SMIN10  1059          
   SMIN11  1060             SMIN12  1061             SMIN13  1062          
   SMIN14  1063             SMIN15  1064             SMIN16  1065          
   SMIN17  1066             SMIN18  1067             SMIN19  1068          
   SMIN20  1069             SMIN21  1070             SMIN22  1071          
   SMIN23  1072             SMIN24  1073             SMIN25  1074          
   SMIN26  1075             SMIN27  1076             SMIN28  1077          
   SMIN29  1078             SMIN30  1079             SMIN31  1080          
   SMIN32  1081             SMIN33  1082             SMIN34  1083          
   SMIN35  1084             SMIN36  1085             SMIN37  1086          
   SMIN38  1087             SMIN39  1088             SMIN40  1089          
   SMIN41  1090             SMIN42  1091             SMIN43  1092          
   SMIN44  1093             SMIN45  1094             SMIN46  1095          
   SMIN47  1096             SMIN48  1097             SMIN49  1098          
   SMIN50  1099             SMIN51  1100             SMIN52  1101          
   SMIN53  1102             SMIN54  1103             SMIN55  1104          
   SMIN56  1105             SMIN57  1106             SMIN58  1107          
   SMIN59  1108             SMIN60  1109             SMIN61  1110          
   SMIN62  1111             SMIN63  1112             SMIN64  1113          
   SMIN65  1114             SMIN66  1115             SMIN67  1116          
   SMIN68  1117             SMIN69  1118             SMIN70  1119          
   SMIN71  1120             SMIN72  1121             SMIN73  1122          
   SMIN74  1123             SMIN75  1124             SMIN76  1125          
   SMIN77  1126             SMIN78  1127             SMIN79  1128          
   SMIN80  1129             SMIN81  1130             SMIN82  1131          
   SMIN83  1132             SMIN84  1133             SMIN85  1134          
   SMIN86  1135             SMIN87  1136             SMIN88  1137          
   SMIN89  1138             SMIN90  1139             SMIN91  1140          
   SMIN92  1141             SMIN93  1142             SMIN94  1143          
   SMIN95  1144             SMIN96  1145             SMIN97  1146          
   SMIN98  1147             SMIN99  1148             SMIN100  1149         
   SMIN101  1150            SMIN102  1151            SMIN103  1152         
   SMIN104  1153            SMIN105  1154            SMIN106  1155         
   SMIN107  1156            SMIN108  1157            SMIN109  1158         
   SMIN110  1159            SMIN111  1160            SMIN112  1161         
   SMIN113  1162            SMIN114  1163            SMIN115  1164         
   SMIN116  1165            SMIN117  1166            SMIN118  1167         
   SMIN119  1168            SMIN120  1169            SMIN121  1170         
   SMIN122  1171            SMIN123  1172            SMIN124  1173         
   SMIN125  1174            SMIN126  1175            SMIN127  1176         
   SMIN128  1177            SMIN129  1178            SMIN130  1179         
   SMIN131  1180            SMIN132  1181            SMIN133  1182         
   SMIN134  1183            SMIN135  1184            SMIN136  1185         
   SMIN137  1186            SMIN138  1187            SMIN139  1188         
   SMIN140  1189            SMIN141  1190            SMIN142  1191         
   SMAX1  1192-1201         SMAX2  1202-1208         SMAX3  1209-1214      
   SMAX4  1215-1220         SMAX5  1221-1226         SMAX6  1227-1232      
   SMAX7  1233-1238         SMAX8  1239-1244         SMAX9  1245-1250      
   SMAX10  1251-1256        SMAX11  1257-1262        SMAX12  1263-1268     
   SMAX13  1269-1274        SMAX14  1275-1280        SMAX15  1281-1286     
   SMAX16  1287-1292        SMAX17  1293-1298        SMAX18  1299-1304     
   SMAX19  1305-1310        SMAX20  1311-1316        SMAX21  1317-1322     
   SMAX22  1323-1328        SMAX23  1329-1334        SMAX24  1335-1340     
   SMAX25  1341-1346        SMAX26  1347-1352        SMAX27  1353-1358     
   SMAX28  1359-1364        SMAX29  1365-1370        SMAX30  1371-1376     
   SMAX31  1377-1382        SMAX32  1383-1388        SMAX33  1389-1394     
   SMAX34  1395-1400        SMAX35  1401-1406        SMAX36  1407-1412     
   SMAX37  1413-1418        SMAX38  1419-1424        SMAX39  1425-1430     
   SMAX40  1431-1436        SMAX41  1437-1442        SMAX42  1443-1448     
   SMAX43  1449-1454        SMAX44  1455-1460        SMAX45  1461-1466     
   SMAX46  1467-1472        SMAX47  1473-1478        SMAX48  1479-1484     
   SMAX49  1485-1490        SMAX50  1491-1496        SMAX51  1497-1502     
   SMAX52  1503-1508        SMAX53  1509-1514        SMAX54  1515-1520     
   SMAX55  1521-1526        SMAX56  1527-1532        SMAX57  1533-1538     
   SMAX58  1539-1544        SMAX59  1545-1550        SMAX60  1551-1556     
   SMAX61  1557-1562        SMAX62  1563-1568        SMAX63  1569-1574     
   SMAX64  1575-1580        SMAX65  1581-1586        SMAX66  1587-1592     
   SMAX67  1593-1598        SMAX68  1599-1604        SMAX69  1605-1610     
   SMAX70  1611-1616        SMAX71  1617-1622        SMAX72  1623-1628     
   SMAX73  1629-1634        SMAX74  1635-1640        SMAX75  1641-1646     
   SMAX76  1647-1652        SMAX77  1653-1658        SMAX78  1659-1664     
   SMAX79  1665-1670        SMAX80  1671-1676        SMAX81  1677-1682     
   SMAX82  1683-1688        SMAX83  1689-1694        SMAX84  1695-1700     
   SMAX85  1701-1706        SMAX86  1707-1712        SMAX87  1713-1718     
   SMAX88  1719-1724        SMAX89  1725-1730        SMAX90  1731-1736     
   SMAX91  1737-1742        SMAX92  1743-1748        SMAX93  1749-1754     
   SMAX94  1755-1760        SMAX95  1761-1766        SMAX96  1767-1772     
   SMAX97  1773-1778        SMAX98  1779-1784        SMAX99  1785-1790     
   SMAX100  1791-1796       SMAX101  1797-1802       SMAX102  1803-1808    
   SMAX103  1809-1814       SMAX104  1815-1820       SMAX105  1821-1826    
   SMAX106  1827-1832       SMAX107  1833-1838       SMAX108  1839-1844    
   SMAX109  1845-1850       SMAX110  1851-1856       SMAX111  1857-1862    
   SMAX112  1863-1868       SMAX113  1869-1874       SMAX114  1875-1880    
   SMAX115  1881-1886       SMAX116  1887-1892       SMAX117  1893-1898    
   SMAX118  1899-1904       SMAX119  1905-1910       SMAX120  1911-1916    
   SMAX121  1917-1922       SMAX122  1923-1928       SMAX123  1929-1934    
   SMAX124  1935-1940       SMAX125  1941-1946       SMAX126  1947-1952    
   SMAX127  1953-1958       SMAX128  1959-1964       SMAX129  1965-1970    
   SMAX130  1971-1976       SMAX131  1977-1982       SMAX132  1983-1988    
   SMAX133  1989-1994       SMAX134  1995-2000       SMAX135  2001-2006    
   SMAX136  2007-2012       SMAX137  2013-2018       SMAX138  2019-2024    
   SMAX139  2025-2030       SMAX140  2031-2036       SMAX141  2037-2042    
   SMAX142  2043-2048       STA1_1 $ 2049-2059       STA1_2 $ 2060-2070    
   STA1_3 $ 2071-2081       STA1_4 $ 2082-2090       STA1_5 $ 2091-2099    
   STA1_6 $ 2100-2109       STA1_7 $ 2110-2118       STA1_8 $ 2119-2127    
   STA1_9 $ 2128-2137       STA1_10 $ 2138-2146      STA1_11 $ 2147-2155   
   STA1_12 $ 2156-2165      STA1_13 $ 2166-2175      STA1_14 $ 2176-2185   
   STA1_15 $ 2186-2194      STA1_16 $ 2195-2204      STA1_17 $ 2205-2214   
   STA1_18 $ 2215-2224      STA1_19 $ 2225-2234      STA1_20 $ 2235-2244   
   STA1_21 $ 2245-2253      STA1_22 $ 2254-2263      STA1_23 $ 2264-2272   
   STA1_24 $ 2273-2281      STA1_25 $ 2282-2290      STA1_26 $ 2291-2300   
   STA1_27 $ 2301-2310      STA1_28 $ 2311-2319      STA1_29 $ 2320-2329   
   STA1_30 $ 2330-2339      STA1_31 $ 2340-2349      STA1_32 $ 2350-2359   
   STA1_33 $ 2360-2368      STA1_34 $ 2369-2378      STA1_35 $ 2379-2387   
   STA1_36 $ 2388-2396      STA1_37 $ 2397-2406      STA1_38 $ 2407-2416   
   STA1_39 $ 2417-2426      STA1_40 $ 2427-2435      STA1_41 $ 2436-2445   
   STA1_42 $ 2446-2455      STA1_43 $ 2456-2465      STA1_44 $ 2466-2474   
   STA1_45 $ 2475-2483      STA1_46 $ 2484-2493      STA1_47 $ 2494-2503   
   STA1_48 $ 2504-2513      STA1_49 $ 2514-2523      STA1_50 $ 2524-2533   
   STA1_51 $ 2534-2543      STA1_52 $ 2544-2553      STA1_53 $ 2554-2563   
   STA1_54 $ 2564-2572      STA1_55 $ 2573-2582      STA1_56 $ 2583-2592   
   STA1_57 $ 2593-2602      STA1_58 $ 2603-2611      STA1_59 $ 2612-2620   
   STA1_60 $ 2621-2630      STA1_61 $ 2631-2640      STA1_62 $ 2641-2650   
   STA1_63 $ 2651-2659      STA1_64 $ 2660-2669      STA1_65 $ 2670-2679   
   STA1_66 $ 2680-2689      STA1_67 $ 2690-2699      STA1_68 $ 2700-2709   
   STA1_69 $ 2710-2719      STA1_70 $ 2720-2728      STA1_71 $ 2729-2737   
   STA1_72 $ 2738-2747      STA1_73 $ 2748-2756      STA1_74 $ 2757-2766   
   STA1_75 $ 2767-2776      STA1_76 $ 2777-2786      STA1_77 $ 2787-2796   
   STA1_78 $ 2797-2805      STA1_79 $ 2806-2815      STA1_80 $ 2816-2825   
   STA1_81 $ 2826-2835      STA1_82 $ 2836-2844      STA1_83 $ 2845-2854   
   STA1_84 $ 2855-2864      STA1_85 $ 2865-2874      STA1_86 $ 2875-2884   
   STA1_87 $ 2885-2894      STA1_88 $ 2895-2903      STA1_89 $ 2904-2913   
   STA1_90 $ 2914-2923      STA1_91 $ 2924-2933      STA1_92 $ 2934-2943   
   STA1_93 $ 2944-2953      STA1_94 $ 2954-2963      STA1_95 $ 2964-2970   
   STA1_96 $ 2971-2977      STA1_97 $ 2978-2983      STA1_98 $ 2984-2990   
   STA1_99 $ 2991-2997      STA1_100 $ 2998-3003     STA1_101 $ 3004-3009  
   STA1_102 $ 3010-3016     STA1_103 $ 3017-3023     STA1_104 $ 3024-3029  
   STA1_105 $ 3030-3036     STA1_106 $ 3037-3043     STA1_107 $ 3044-3050  
   STA1_108 $ 3051-3057     STA1_109 $ 3058-3064     STA1_110 $ 3065-3070  
   STA1_111 $ 3071-3076     STA1_112 $ 3077-3082     STA1_113 $ 3083-3088  
   STA1_114 $ 3089-3094     STA1_115 $ 3095-3100     STA1_116 $ 3101-3106  
   STA1_117 $ 3107-3112     STA1_118 $ 3113-3118     STA1_119 $ 3119-3124  
   STA1_120 $ 3125-3130     STA1_121 $ 3131-3136     STA1_122 $ 3137-3142  
   STA1_123 $ 3143-3148     STA1_124 $ 3149-3154     STA1_125 $ 3155-3160  
   STA1_126 $ 3161-3166     STA1_127 $ 3167-3169     STA1_128 $ 3170-3175  
   STA1_129 $ 3176-3181     STA1_130 $ 3182-3187     STA1_131 $ 3188-3193  
   STA1_132 $ 3194-3199     STA1_133 $ 3200-3202     STA1_134 $ 3203-3208  
   STA1_135 $ 3209-3214     STA1_136 $ 3215-3220     STA1_137 $ 3221-3223  
   STA1_138 $ 3224-3229     STA1_139 $ 3230-3235     STA1_140 $ 3236-3241  
   STA1_141 $ 3242-3247     STA1_142 $ 3248-3252     STA2_1 $ 3253-3263    
   STA2_2 $ 3264-3274       STA2_3 $ 3275-3283       STA2_4 $ 3284-3294    
   STA2_5 $ 3295-3305       STA2_6 $ 3306-3314       STA2_7 $ 3315-3324    
   STA2_8 $ 3325-3334       STA2_9 $ 3335-3343       STA2_10 $ 3344-3353   
   STA2_11 $ 3354-3363      STA2_12 $ 3364-3372      STA2_13 $ 3373-3381   
   STA2_14 $ 3382-3390      STA2_15 $ 3391-3400      STA2_16 $ 3401-3409   
   STA2_17 $ 3410-3418      STA2_18 $ 3419-3427      STA2_19 $ 3428-3436   
   STA2_20 $ 3437-3445      STA2_21 $ 3446-3455      STA2_22 $ 3456-3464   
   STA2_23 $ 3465-3474      STA2_24 $ 3475-3484      STA2_25 $ 3485-3494   
   STA2_26 $ 3495-3503      STA2_27 $ 3504-3512      STA2_28 $ 3513-3522   
   STA2_29 $ 3523-3531      STA2_30 $ 3532-3540      STA2_31 $ 3541-3549   
   STA2_32 $ 3550-3558      STA2_33 $ 3559-3568      STA2_34 $ 3569-3577   
   STA2_35 $ 3578-3587      STA2_36 $ 3588-3597      STA2_37 $ 3598-3606   
   STA2_38 $ 3607-3615      STA2_39 $ 3616-3624      STA2_40 $ 3625-3634   
   STA2_41 $ 3635-3643      STA2_42 $ 3644-3652      STA2_43 $ 3653-3661   
   STA2_44 $ 3662-3671      STA2_45 $ 3672-3681      STA2_46 $ 3682-3690   
   STA2_47 $ 3691-3699      STA2_48 $ 3700-3708      STA2_49 $ 3709-3717   
   STA2_50 $ 3718-3726      STA2_51 $ 3727-3735      STA2_52 $ 3736-3744   
   STA2_53 $ 3745-3753      STA2_54 $ 3754-3763      STA2_55 $ 3764-3772   
   STA2_56 $ 3773-3781      STA2_57 $ 3782-3790      STA2_58 $ 3791-3800   
   STA2_59 $ 3801-3810      STA2_60 $ 3811-3819      STA2_61 $ 3820-3828   
   STA2_62 $ 3829-3837      STA2_63 $ 3838-3847      STA2_64 $ 3848-3856   
   STA2_65 $ 3857-3865      STA2_66 $ 3866-3874      STA2_67 $ 3875-3883   
   STA2_68 $ 3884-3892      STA2_69 $ 3893-3901      STA2_70 $ 3902-3911   
   STA2_71 $ 3912-3921      STA2_72 $ 3922-3930      STA2_73 $ 3931-3940   
   STA2_74 $ 3941-3949      STA2_75 $ 3950-3958      STA2_76 $ 3959-3967   
   STA2_77 $ 3968-3976      STA2_78 $ 3977-3986      STA2_79 $ 3987-3995   
   STA2_80 $ 3996-4004      STA2_81 $ 4005-4013      STA2_82 $ 4014-4023   
   STA2_83 $ 4024-4032      STA2_84 $ 4033-4041      STA2_85 $ 4042-4050   
   STA2_86 $ 4051-4059      STA2_87 $ 4060-4068      STA2_88 $ 4069-4078   
   STA2_89 $ 4079-4087      STA2_90 $ 4088-4096      STA2_91 $ 4097-4105   
   STA2_92 $ 4106-4114      STA2_93 $ 4115-4123      STA2_94 $ 4124-4132   
   STA2_95 $ 4133-4138      STA2_96 $ 4139-4144      STA2_97 $ 4145-4151   
   STA2_98 $ 4152-4157      STA2_99 $ 4158-4163      STA2_100 $ 4164-4169  
   STA2_101 $ 4170-4176     STA2_102 $ 4177-4182     STA2_103 $ 4183-4188  
   STA2_104 $ 4189-4195     STA2_105 $ 4196-4201     STA2_106 $ 4202-4207  
   STA2_107 $ 4208-4213     STA2_108 $ 4214-4219     STA2_109 $ 4220-4225  
   STA2_110 $ 4226-4231     STA2_111 $ 4232-4238     STA2_112 $ 4239-4241  
   STA2_113 $ 4242-4244     STA2_114 $ 4245-4247     STA2_115 $ 4248-4250  
   STA2_116 $ 4251-4253     STA2_117 $ 4254-4256     STA2_118 $ 4257-4259  
   STA2_119 $ 4260-4262     STA2_120 $ 4263-4265     STA2_121 $ 4266-4268  
   STA2_122 $ 4269-4271     STA2_123 $ 4272-4274     STA2_124 $ 4275-4277  
   STA2_125 $ 4278-4280     STA2_126 $ 4281-4283     STA2_127 $ 4284-4289  
   STA2_128 $ 4290-4292     STA2_129 $ 4293-4295     STA2_130 $ 4296-4298  
   STA2_131 $ 4299-4301     STA2_132 $ 4302-4304     STA2_133 $ 4305-4310  
   STA2_134 $ 4311-4313     STA2_135 $ 4314-4316     STA2_136 $ 4317-4319  
   STA2_137 $ 4320-4325     STA2_138 $ 4326-4328     STA2_139 $ 4329-4331  
   STA2_140 $ 4332-4334     STA2_141 $ 4335-4337     STA2_142 $ 4338       
   STA3_1 $ 4339-4347       STA3_2 $ 4348-4356       STA3_3 $ 4357-4363    
   STA3_4 $ 4364-4369       STA3_5 $ 4370-4375       STA3_6 $ 4376-4383    
   STA3_7 $ 4384-4390       STA3_8 $ 4391            STA3_9 $ 4392         
   STA3_10 $ 4393-4398      STA3_11 $ 4399-4404      STA3_12 $ 4405        
   STA3_13 $ 4406           STA3_14 $ 4407           STA3_15 $ 4408        
   STA3_16 $ 4409           STA3_17 $ 4410           STA3_18 $ 4411        
   STA3_19 $ 4412           STA3_20 $ 4413           STA3_21 $ 4414        
   STA3_22 $ 4415           STA3_23 $ 4416           STA3_24 $ 4417        
   STA3_25 $ 4418           STA3_26 $ 4419           STA3_27 $ 4420        
   STA3_28 $ 4421           STA3_29 $ 4422           STA3_30 $ 4423        
   STA3_31 $ 4424           STA3_32 $ 4425           STA3_33 $ 4426        
   STA3_34 $ 4427           STA3_35 $ 4428           STA3_36 $ 4429        
   STA3_37 $ 4430           STA3_38 $ 4431           STA3_39 $ 4432        
   STA3_40 $ 4433           STA3_41 $ 4434           STA3_42 $ 4435        
   STA3_43 $ 4436           STA3_44 $ 4437           STA3_45 $ 4438        
   STA3_46 $ 4439           STA3_47 $ 4440           STA3_48 $ 4441        
   STA3_49 $ 4442           STA3_50 $ 4443           STA3_51 $ 4444        
   STA3_52 $ 4445           STA3_53 $ 4446           STA3_54 $ 4447        
   STA3_55 $ 4448           STA3_56 $ 4449           STA3_57 $ 4450        
   STA3_58 $ 4451           STA3_59 $ 4452           STA3_60 $ 4453        
   STA3_61 $ 4454           STA3_62 $ 4455           STA3_63 $ 4456        
   STA3_64 $ 4457           STA3_65 $ 4458           STA3_66 $ 4459        
   STA3_67 $ 4460           STA3_68 $ 4461           STA3_69 $ 4462        
   STA3_70 $ 4463           STA3_71 $ 4464           STA3_72 $ 4465        
   STA3_73 $ 4466           STA3_74 $ 4467           STA3_75 $ 4468        
   STA3_76 $ 4469           STA3_77 $ 4470           STA3_78 $ 4471        
   STA3_79 $ 4472           STA3_80 $ 4473           STA3_81 $ 4474        
   STA3_82 $ 4475           STA3_83 $ 4476           STA3_84 $ 4477        
   STA3_85 $ 4478           STA3_86 $ 4479           STA3_87 $ 4480        
   STA3_88 $ 4481           STA3_89 $ 4482           STA3_90 $ 4483        
   STA3_91 $ 4484           STA3_92 $ 4485           STA3_93 $ 4486        
   STA3_94 $ 4487           STA3_95 $ 4488           STA3_96 $ 4489        
   STA3_97 $ 4490           STA3_98 $ 4491           STA3_99 $ 4492        
   STA3_100 $ 4493          STA3_101 $ 4494          STA3_102 $ 4495       
   STA3_103 $ 4496          STA3_104 $ 4497          STA3_105 $ 4498       
   STA3_106 $ 4499          STA3_107 $ 4500          STA3_108 $ 4501       
   STA3_109 $ 4502          STA3_110 $ 4503          STA3_111 $ 4504       
   STA3_112 $ 4505          STA3_113 $ 4506          STA3_114 $ 4507       
   STA3_115 $ 4508          STA3_116 $ 4509          STA3_117 $ 4510       
   STA3_118 $ 4511          STA3_119 $ 4512          STA3_120 $ 4513       
   STA3_121 $ 4514          STA3_122 $ 4515          STA3_123 $ 4516       
   STA3_124 $ 4517          STA3_125 $ 4518          STA3_126 $ 4519       
   STA3_127 $ 4520          STA3_128 $ 4521          STA3_129 $ 4522       
   STA3_130 $ 4523          STA3_131 $ 4524          STA3_132 $ 4525       
   STA3_133 $ 4526          STA3_134 $ 4527          STA3_135 $ 4528       
   STA3_136 $ 4529          STA3_137 $ 4530          STA3_138 $ 4531       
   STA3_139 $ 4532          STA3_140 $ 4533          STA3_141 $ 4534       
   STA3_142 $ 4535          NWSTAT1 $ 4536-4546      NWSTAT2 $ 4547-4557   
   NWSTAT3 $ 4558-4567      NWSTAT4 $ 4568-4576      NWSTAT5 $ 4577-4583   
   NWSTAT6 $ 4584-4589      NWSTAT7 $ 4590-4594      NOUSTAT  4595         
   AMENDYR  4596-4599       BASEFINE  4600-4608      CH2APP  4609          
   CH8FINGD  4610           CMSRVORD  4611           COMPLYPR  4612        
   COSTASSM  4613           FINOFFST  4614-4618      FORFEITR  4619-4626   
   GLFINMAX  4627-4635      GLFINMIN  4636-4644      REMEDORD  4645        
   VICTNOTE  4646           BOOKERCD  4647-4648      QUARTER  4649         
   RETEXT1 $ 4650           RETEXT2 $ 4651           RETEXT3 $ 4652        
   RETEXT4 $ 4653           RETEXT5 $ 4654           RETEXT6 $ 4655        
   RETEXT7 $ 4656           RETEXT8 $ 4657           RETEXT9 $ 4658        
   RETEXT10 $ 4659          REAS1  4660-4662         REAS2  4663-4665      
   REAS3  4666              REAS4  4667              REAS5  4668           
   REAS6  4669              REAS7  4670              REAS8  4671           
   REAS9  4672              REAS10  4673             INPLEA1  4674         
   INPLEA2  4675            INPLEA3  4676            INPLEA4  4677         
   INPLEA5  4678            INPLEA6  4679            INPLEA7  4680         
   INPLEA8  4681            INPLEA9  4682            INPLEA10  4683        
   INPLEA11  4684           INPLEA12  4685           INNOPL1  4686         
   INNOPL2  4687            INNOPL3  4688            INNOPL4  4689         
   INNOPL5  4690            INNOPL6  4691            INNOPL7  4692         
   INNOPL8  4693            INNOPL9  4694            INNOPL10  4695        
   INNOPL11  4696           INNOPL12  4697           SENTYR  4698-4701     
   BOOKER2  4702            BOOKER3  4703            NEWCNVTN  4704        
   RESTCAT  4705            FINECAT  4706            SUSFNCAT  4707        
   LCAT1  4708              LCAT2  4709              LCATHI  4710          
   LCATS1  4711             LCATS2  4712             LCATSHI  4713         
   LCATR1  4714             LCATR2  4715             LCATRHI  4716         
   LCATC1  4717             LCATC2  4718             LCATCHI  4719         
 ;                       

LENGTH
   DISGORGE 3               CPIDN 6                  PSR 3                 
   JANDC 3                  PLEA 3                   REASONS 3             
   INDICT 3                 SENTRANS 3               WRKSHT 3              
   INCORPYR 4               INCORLOC 3               ORGTYPE 3             
   BUSCLAS 4                FTEMNUM 6                FTEMSIGN 3            
   SELFREP 3                HSMISCND 3               PRCRIME 3             
   PRCIVIL 3                OWNSTRCT 3               FINSTDS 3             
   FINSTDO 3                OFFENSE1 3               OFFENSE2 3            
   OFFENSE3 3               PRIMOFF 3                NOCOUNTS 4            
   SOURCES 3                OFFLVL 3                 DETBFINE 3            
   TOLERNCE 3               HISTORY 3                VIOLATE 3             
   OBSTRUCT 3               COMPLY 3                 ACCEPT 3              
   CCULPSCO 3               FCULPSCO 3               DISPOSIT 3            
   PROBATN 3                COFI 3                   PROBMON 3             
   ORDERCE 3                TYPEOTHS 3               CRIMPURP 3            
   CANTPAY 3                ADJOFL1 3                ADJOFL2 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_PHI 3                BASADJ1 3                BASADJ2 3             
   BASADJHI 3               BASE1 3                  BASE2 3               
   BASEHI 3                 ADJOFR1 3                ADJOFR2 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_PHI 3               BASADR1 3                BASADR2 3             
   BASADRHI 3               BASER1 3                 BASER2 3              
   BASERHI 3                ADJOFS1 3                ADJOFS2 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_PHI 3               BASADS1 3                BASADS2 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASESHI 3                ADJOFC1 3                ADJOFC2 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_PHI 3               BASADC1 3                BASADC2 3             
   BASADCHI 3               BASEC1 3                 BASEC2 3              
   BASECHI 3                NOCOMP 3                 SMIN1 4               
   SMIN2 3                  SMIN3 3                  SMIN4 3               
   SMIN5 3                  SMIN6 3                  SMIN7 3               
   SMIN8 3                  SMIN9 3                  SMIN10 3              
   SMIN11 3                 SMIN12 3                 SMIN13 3              
   SMIN14 3                 SMIN15 3                 SMIN16 3              
   SMIN17 3                 SMIN18 3                 SMIN19 3              
   SMIN20 3                 SMIN21 3                 SMIN22 3              
   SMIN23 3                 SMIN24 3                 SMIN25 3              
   SMIN26 3                 SMIN27 3                 SMIN28 3              
   SMIN29 3                 SMIN30 3                 SMIN31 3              
   SMIN32 3                 SMIN33 3                 SMIN34 3              
   SMIN35 3                 SMIN36 3                 SMIN37 3              
   SMIN38 3                 SMIN39 3                 SMIN40 3              
   SMIN41 3                 SMIN42 3                 SMIN43 3              
   SMIN44 3                 SMIN45 3                 SMIN46 3              
   SMIN47 3                 SMIN48 3                 SMIN49 3              
   SMIN50 3                 SMIN51 3                 SMIN52 3              
   SMIN53 3                 SMIN54 3                 SMIN55 3              
   SMIN56 3                 SMIN57 3                 SMIN58 3              
   SMIN59 3                 SMIN60 3                 SMIN61 3              
   SMIN62 3                 SMIN63 3                 SMIN64 3              
   SMIN65 3                 SMIN66 3                 SMIN67 3              
   SMIN68 3                 SMIN69 3                 SMIN70 3              
   SMIN71 3                 SMIN72 3                 SMIN73 3              
   SMIN74 3                 SMIN75 3                 SMIN76 3              
   SMIN77 3                 SMIN78 3                 SMIN79 3              
   SMIN80 3                 SMIN81 3                 SMIN82 3              
   SMIN83 3                 SMIN84 3                 SMIN85 3              
   SMIN86 3                 SMIN87 3                 SMIN88 3              
   SMIN89 3                 SMIN90 3                 SMIN91 3              
   SMIN92 3                 SMIN93 3                 SMIN94 3              
   SMIN95 3                 SMIN96 3                 SMIN97 3              
   SMIN98 3                 SMIN99 3                 SMIN100 3             
   SMIN101 3                SMIN102 3                SMIN103 3             
   SMIN104 3                SMIN105 3                SMIN106 3             
   SMIN107 3                SMIN108 3                SMIN109 3             
   SMIN110 3                SMIN111 3                SMIN112 3             
   SMIN113 3                SMIN114 3                SMIN115 3             
   SMIN116 3                SMIN117 3                SMIN118 3             
   SMIN119 3                SMIN120 3                SMIN121 3             
   SMIN122 3                SMIN123 3                SMIN124 3             
   SMIN125 3                SMIN126 3                SMIN127 3             
   SMIN128 3                SMIN129 3                SMIN130 3             
   SMIN131 3                SMIN132 3                SMIN133 3             
   SMIN134 3                SMIN135 3                SMIN136 3             
   SMIN137 3                SMIN138 3                SMIN139 3             
   SMIN140 3                SMIN141 3                SMIN142 3             
   SMAX1 6                  SMAX2 6                  SMAX3 6               
   SMAX4 6                  SMAX5 6                  SMAX6 6               
   SMAX7 6                  SMAX8 6                  SMAX9 6               
   SMAX10 6                 SMAX11 6                 SMAX12 6              
   SMAX13 6                 SMAX14 6                 SMAX15 6              
   SMAX16 6                 SMAX17 6                 SMAX18 6              
   SMAX19 6                 SMAX20 6                 SMAX21 6              
   SMAX22 6                 SMAX23 6                 SMAX24 6              
   SMAX25 6                 SMAX26 6                 SMAX27 6              
   SMAX28 6                 SMAX29 6                 SMAX30 6              
   SMAX31 6                 SMAX32 6                 SMAX33 6              
   SMAX34 6                 SMAX35 6                 SMAX36 6              
   SMAX37 6                 SMAX38 6                 SMAX39 6              
   SMAX40 6                 SMAX41 6                 SMAX42 6              
   SMAX43 6                 SMAX44 6                 SMAX45 6              
   SMAX46 6                 SMAX47 6                 SMAX48 6              
   SMAX49 6                 SMAX50 6                 SMAX51 6              
   SMAX52 6                 SMAX53 6                 SMAX54 6              
   SMAX55 6                 SMAX56 6                 SMAX57 6              
   SMAX58 6                 SMAX59 6                 SMAX60 6              
   SMAX61 6                 SMAX62 6                 SMAX63 6              
   SMAX64 6                 SMAX65 6                 SMAX66 6              
   SMAX67 6                 SMAX68 6                 SMAX69 6              
   SMAX70 6                 SMAX71 6                 SMAX72 6              
   SMAX73 6                 SMAX74 6                 SMAX75 6              
   SMAX76 6                 SMAX77 6                 SMAX78 6              
   SMAX79 6                 SMAX80 6                 SMAX81 6              
   SMAX82 6                 SMAX83 6                 SMAX84 6              
   SMAX85 6                 SMAX86 6                 SMAX87 6              
   SMAX88 6                 SMAX89 6                 SMAX90 6              
   SMAX91 6                 SMAX92 6                 SMAX93 6              
   SMAX94 6                 SMAX95 6                 SMAX96 6              
   SMAX97 6                 SMAX98 6                 SMAX99 6              
   SMAX100 6                SMAX101 6                SMAX102 6             
   SMAX103 6                SMAX104 6                SMAX105 6             
   SMAX106 6                SMAX107 6                SMAX108 6             
   SMAX109 6                SMAX110 6                SMAX111 6             
   SMAX112 6                SMAX113 6                SMAX114 6             
   SMAX115 6                SMAX116 6                SMAX117 6             
   SMAX118 6                SMAX119 6                SMAX120 6             
   SMAX121 6                SMAX122 6                SMAX123 6             
   SMAX124 6                SMAX125 6                SMAX126 6             
   SMAX127 6                SMAX128 6                SMAX129 6             
   SMAX130 6                SMAX131 6                SMAX132 6             
   SMAX133 6                SMAX134 6                SMAX135 6             
   SMAX136 6                SMAX137 6                SMAX138 6             
   SMAX139 6                SMAX140 6                SMAX141 6             
   SMAX142 6                NOUSTAT 3                AMENDYR 4             
   BASEFINE 6               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COMPLYPR 3               COSTASSM 3            
   FINOFFST 4               FORFEITR 6               GLFINMAX 6            
   GLFINMIN 6               REMEDORD 3               VICTNOTE 3            
   BOOKERCD 3               QUARTER 3                REAS1 4               
   REAS2 4                  REAS3 3                  REAS4 3               
   REAS5 3                  REAS6 3                  REAS7 3               
   REAS8 3                  REAS9 3                  REAS10 3              
   INPLEA1 3                INPLEA2 3                INPLEA3 3             
   INPLEA4 3                INPLEA5 3                INPLEA6 3             
   INPLEA7 3                INPLEA8 3                INPLEA9 3             
   INPLEA10 3               INPLEA11 3               INPLEA12 3            
   INNOPL1 3                INNOPL2 3                INNOPL3 3             
   INNOPL4 3                INNOPL5 3                INNOPL6 3             
   INNOPL7 3                INNOPL8 3                INNOPL9 3             
   INNOPL10 3               INNOPL11 3               INNOPL12 3            
   SENTYR 4                 BOOKER2 3                BOOKER3 3             
   NEWCNVTN 3               RESTCAT 3                FINECAT 3             
   SUSFNCAT 3               LCAT1 3                  LCAT2 3               
   LCATHI 3                 LCATS1 3                 LCATS2 3              
   LCATSHI 3                LCATR1 3                 LCATR2 3              
   LCATRHI 3                LCATC1 3                 LCATC2 3              
   LCATCHI 3 ;

         

RUN ;
